import java.applet.Applet;
import java.io.FileOutputStream;
import java.util.Properties;

import javax.swing.JFrame;
import javax.swing.JMenu;

import quadbase.chart.designer.IByPassSaveAsForChart;
import quadbase.chart.designer.IChartIO;
import quadbase.chart.designer.QbChartDesigner;
import quadbase.reportdesigner.designer.IByPassSaveAsForReport;
import quadbase.reportdesigner.designer.IReportNavigationIO;
import quadbase.reportdesigner.designer.QbReportDesigner;
import quadbase.reportorganizer.manager.IChartHandle;
import quadbase.reportorganizer.manager.IReportHandle;
import quadbase.reportorganizer.organizerAPI.QbOrganizer;


public class CustomOrganizerERES extends Applet {

	static final long serialVersionUID = 1;
	
	public static void main(String[] args) {
		try {
			CustomOrganizerERES organizer = new CustomOrganizerERES();
			organizer.startDesigner();
		} catch (Exception ex) {
			ex.printStackTrace();
		}

	}
	
	public void init() {
		startDesigner();
	}

	void startDesigner() {
		try {
			QbOrganizer.setServletRunner("http://localhost:8080");
			QbOrganizer.setServletContext("ERES/servlet");
			QbOrganizer organizer = new QbOrganizer(null, "admin", "admin");
			
			//	modify organizer's reportdesigner
			organizer.setReportDesignerHandle(new ReportDesignerHandle());
			
			// modify organizer's chartdesigner
			organizer.setChartDesignerHandle(new ChartDesignerHandle());
			
			// set organizer visible
			JFrame frame = organizer.getOrganizerUI();
			frame.setVisible(true);

		} catch (Exception ex) { ex.printStackTrace(); }
	}

	public static class ReportDesignerHandle implements IReportHandle {

		public ReportDesignerHandle() {};

		public void processDesigner(QbReportDesigner designer) {
			System.out.println("PROCESS REPORT....");
			
			//	modify warning message before inserting drill-down layer
			designer.modifyWarningMessage(QbReportDesigner.SAVE_RPT_BEFORE_DRILLDOWN, "The report designer will save the current report for you, continue?");
			
			//	modify warning message before inserting subreport
			designer.modifyWarningMessage(QbReportDesigner.SAVE_RPT_BEFORE_SUBREPORT, "The report designer will save the current report for you, continue?");
			
			// customize report IO
			designer.setReportIO(new ReportIO(designer));
			
			//	by pass SAVE AS IO
			designer.setByPassSaveAsIO(new ByPassSaveAsForReport());
			
			//	modify reportdesigner's chartdesigner
			designer.setChartDesignerHandle(new ChartDesignerHandle());
			
			//	remove "SAVE AS" option for Report Designer
			JMenu fileMenu = designer.getReportMenuBar().getMenu(0);
			fileMenu.remove(6);
		}
	}

	public static class ReportIO implements IReportNavigationIO {
		String fileName = null;
		QbReportDesigner designer = null;

		public ReportIO(QbReportDesigner designer) { this.designer = designer; }

		public void saveFile(byte[] data, String fileName) {
			System.out.println("SAVE REPORT FILE - " + fileName);
			try {
				FileOutputStream fout = new FileOutputStream(fileName);
				fout.write(data, 0, data.length);
				fout.close();
			} catch (Exception ex) {
				ex.printStackTrace();
			}

			this.fileName = fileName;
		}

		// if parent report is saved, return saved report file location
		// else return null;
		public String isParentReportSaved() {
			System.out.println("IS PARENT REPORT SAVED = NO...");
			return null;
		}

		// overridden save parent report method and return parent report location
		public String saveParentReport() {
			System.out.println("RETURN PARENT REPORT LOCATION");
			return fileName;
		}
	}

	public static class ByPassSaveAsForReport implements IByPassSaveAsForReport {

		public ByPassSaveAsForReport() {};

		public String getFileName(String originalFileName) {
			System.out.println("BY PASS REPORT SAVE AS OPTION...");
			if (originalFileName == null) return "TEMP_REPORT_FILE.rpt";
			else return originalFileName;
		}

		public Properties getSaveAsProperties(String originalFileName) {
			return new Properties();
		}
	}

	public static class ChartDesignerHandle implements IChartHandle {

		public ChartDesignerHandle() {};

		public void processDesigner(QbChartDesigner designer) {
			System.out.println("PROCESS CHART....");
			
			// remove "SAVE AS" option for Chart Designer
			JMenu fileMenu = designer.getChartMenuBar().getMenu(0);
			fileMenu.remove(6);
			
			designer.setChartIO(new ChartIO());
			designer.setByPassSaveAsIO(new ByPassSaveAsForChart());
		}

	}

	public static class ChartIO implements IChartIO {

		public ChartIO() {};
		
		public String saveChartFile(byte[] data, String fileName) {

			System.out.println("SAVE CHART FILE - " + fileName);
			try {

				FileOutputStream fout = new FileOutputStream(fileName);
				fout.write(data, 0, data.length);
				fout.close();

			} catch (Exception ex) {

				ex.printStackTrace();

			}

			return fileName;

		}

	}

	public static class ByPassSaveAsForChart implements IByPassSaveAsForChart {

		public ByPassSaveAsForChart() {};

		public String getFileName(String originalFileName) {

			System.out.println("BY PASS CHART SAVE AS OPTION...");
			if (originalFileName == null) return "TEMP_CHART_FILE.cht";
			else return originalFileName;

		}

		public Properties getSaveAsProperties(String originalFileName) {

			return new Properties();

		}

	}

}
